#! /bin/bash

menu(){
	printf "\n"
	printf "\033[44m \033[1;96m ****************** SysRanger Probe Menu ****************** \033[0m \n"
		
	echo "  1 Status" 
	echo "  2 View" 
	echo "  3 Stop"
	echo "  4 Restart"
	echo "  5 Update" 
	echo "  6 Remove Service"	
	echo "  7 Install Service"	
	echo "  8 Configuration"
	echo "  0 Quit" 
}



setJava(){
	export JAVA_HOME=$PWD/jrex
	export PATH=$JAVA_HOME/bin:$PATH
}


config(){
	echo "Please enter the hostname and port of SysRanger Server. Leave port empty for default [8300]."
	echo
	read -p "Enter  Server Hostname or IP: " HOST
	[ -z $HOST ]&&return
	read -p "Enter  Server Port: " portInput
	PORT="${portInput:=8300}" 
cat <<EOF > config.ini
server.host=$HOST
server.port=$PORT
EOF
	restartService
}



view(){
	pkill -9 -f SysRangerProbeViewer.jar
	setJava
	java -jar $PWD/SysRangerProbeViewer.jar
}

status(){
	systemctl status sysrangerprobe
}

stopService(){
	echo "Stopping service... [This may take up 90 seconds]"
	systemctl stop sysrangerprobe
	pkill -9 -f SysRangerProbe.jar
	rm singleinstancesignal > /dev/null 2>&1
	rm singleinstancelock > /dev/null 2>&1
}


restartService(){
	stopService
	echo "Starting service..."
	systemctl restart sysrangerprobe
}

installService(){
	sh installservice.sh
}

removeService(){
	stopService
	echo "Disabling Service..."
	systemctl disable sysrangerprobe.service
	systemctl daemon-reload
	echo "Killing app..."
	pkill -f SysRangerProbe.jar
	echo "Removing service"
	rm /etc/systemd/system/sysrangerprobe.service
}

update(){
	echo 
	echo "Please enter the hostname of SysRanger Server. SysRanger Server's 8100 port must be reachable in order to get update files."
	echo "Leave hostname empty for downloading directly from  internet (sysranger.com)."
	echo
	read -p "Enter  Server Hostname or IP: " HOST
	if [ -z $HOST ];then 
		updateFromInternet
		return
	fi
	stopService
	echo "Downloading updater..."
	sudo wget --no-cache -O Updater.jar http://$HOST:8100/files/downloads/updater/latest/Updater.jar?v=$(date +%s)
	setJava
	cd $PWD
	java -jar Updater.jar -app SysRangerProbe -wait -host $HOST:8100
	updateFinished
}

updateFromInternet(){
	stopService
	echo "Downloading updater..."
	sudo wget --no-cache -O Updater.jar https://monitor.sysranger.com/files/downloads/updater/latest/Updater.jar?v=$(date +%s)
	setJava
	cd $PWD
	java -jar Updater.jar -app SysRangerProbe -wait
	updateFinished
}


updateFinished(){
	chmod +x *.sh
	chmod +x jrex/bin/java
	chmod +x jrex/lib/jspawnhelper
	rm *.bat
	rm *.exe
	echo "Starting..."
	systemctl restart sysrangerprobe
}

redirect(){
	case "$1" in
		config)config;;
		status)status;;
		stop)stopService;;
		restart)restartService;;
		view)view;;
		remove)removeService;;
		update)update;;
		install)installService;;
		*) echo "Incorrect operation $1"  ;;
	esac
}






showMenu(){
	while true
	do
		menu
		read n
		case $n in
			1) status;;
			2) view;;
			3) stopService;;
			4) restartService;;
			5) update;;
			6) removeService;;
			7) installService;;
			8) config;;
			0) break 2;;
			*) echo "invalid option";;
		esac
	done
}




if [ -n "$1" ]; then
	redirect $1
else
	showMenu
fi


